@@ -1,6 +1,6 @@
 package DBM::Deep::Engine::File;
 
-use 5.008_000;
+use 5.006_000;
 
 use strict;
 use warnings FATAL => 'all';
@@ -24,7 +24,6 @@ sub SIG_FILE     () { 'DPDB' }
 sub SIG_HEADER   () { 'h'    }
 sub SIG_NULL     () { 'N'    }
 sub SIG_DATA     () { 'D'    }
-sub SIG_UNIDATA  () { 'U'    }
 sub SIG_INDEX    () { 'I'    }
 sub SIG_BLIST    () { 'B'    }
 sub SIG_FREE     () { 'F'    }
@@ -77,8 +76,6 @@ sub new {
 
         entries => {}, # This is the list of entries for transactions
         storage => undef,
-
-        external_refs => undef,
     }, $class;
 
     # Never allow byte_size to be set directly.
@@ -301,13 +298,6 @@ sub write_value {
     if ( !defined $value ) {
         $class = 'DBM::Deep::Sector::File::Null';
     }
-    elsif ( ref $value eq 'DBM::Deep::Null' ) {
-        DBM::Deep::_warnif(
-             'uninitialized', 'Assignment of stale reference'
-        );
-        $class = 'DBM::Deep::Sector::File::Null';
-        $value = undef;
-    }
     elsif ( $r eq 'ARRAY' || $r eq 'HASH' ) {
         my $tmpvar;
         if ( $r eq 'ARRAY' ) {
@@ -600,7 +590,7 @@ sub get_running_txn_ids {
 =head2 get_txn_staleness_counter( $trans_id )
 
 This will return the staleness counter for the given transaction ID. Please see
-L<DBM::Deep::Engine/STALENESS> for more information.
+L</TRANSACTION STALENESS> for more information.
 
 =cut
 
@@ -622,7 +612,7 @@ sub get_txn_staleness_counter {
 =head2 inc_txn_staleness_counter( $trans_id )
 
 This will increment the staleness counter for the given transaction ID. Please see
-L<DBM::Deep::Engine/STALENESS> for more information.
+L</TRANSACTION STALENESS> for more information.
 
 =cut
 
@@ -724,8 +714,7 @@ settings that set how the file is interpreted.
 
 {
     my $header_fixed = length( __PACKAGE__->SIG_FILE ) + 1 + 4 + 4;
-    my $this_file_version = 4;
-    my $min_file_version = 3;
+    my $this_file_version = 3;
 
     sub _write_file_header {
         my $self = shift;
@@ -761,8 +750,6 @@ settings that set how the file is interpreted.
         $self->set_trans_loc( $header_fixed + 4 );
         $self->set_chains_loc( $header_fixed + 4 + $bl + $STALE_SIZE * ($nt-1) );
 
-        $self->{v} = $this_file_version;
-
         return;
     }
 
@@ -786,25 +773,13 @@ settings that set how the file is interpreted.
             DBM::Deep->_throw_error( "Pre-1.00 file version found" );
         }
 
-        if ( $file_version < $min_file_version ) {
+        unless ( $file_version == $this_file_version ) {
             $self->storage->close;
             DBM::Deep->_throw_error(
-                "This file version is too old - "
-              . _guess_version($file_version) .
-                " - expected " . _guess_version($min_file_version)
-              . " to " . _guess_version($this_file_version)
+                "Wrong file version found - " .  $file_version .
+                " - expected " . $this_file_version
             );
         }
-        if ( $file_version > $this_file_version ) {
-            $self->storage->close;
-            DBM::Deep->_throw_error(
-                "This file version is too new - probably "
-              . _guess_version($file_version) .
-                " - expected " . _guess_version($min_file_version)
-              . " to " . _guess_version($this_file_version)
-            );
-        }
-        $self->{v} = $file_version;
 
         my $buffer2 = $self->storage->read_at( undef, $size );
         my @values = unpack( 'C C C C', $buffer2 );
@@ -834,16 +809,6 @@ settings that set how the file is interpreted.
 
         return length($buffer) + length($buffer2);
     }
-
-    sub _guess_version {
-        $_[0] == 4 and return  2;
-        $_[0] == 3 and return '1.0003';
-        $_[0] == 2 and return '1.00';
-        $_[0] == 1 and return '0.99';
-        $_[0] == 0 and return '0.91';
-
-        return $_[0]-2;
-    }
 }
 
 =head2 _apply_digest( @stuff )
@@ -855,9 +820,7 @@ passed in and return the result.
 
 sub _apply_digest {
     my $self = shift;
-    my $victim = shift;
-    utf8::encode $victim if $self->{v} >= 4;
-    return $self->{digest}->($victim);
+    return $self->{digest}->(@_);
 }
 
 =head2 _add_free_blist_sector( $offset, $size )
@@ -1043,14 +1006,11 @@ sub supports {
     shift;
     my ($feature) = @_;
 
-    return 1 if $feature =~ /^(?:(?:transacti|singlet)ons|unicode)\z/;
+    return 1 if $feature eq 'transactions';
+    return 1 if $feature eq 'singletons';
     return;
 }
 
-sub db_version {
-    return $_[0]{v} == 3 ? '1.0003' : 2;
-}
-
 sub clear {
     my $self = shift;
     my $obj = shift;
@@ -1137,7 +1097,7 @@ sub _dump_file {
         }
         else {
             $return .= sprintf "%08d: %s  %04d", $spot, $sector->type, $sector->size;
-            if ( $sector->type =~ /^[DU]\z/ ) {
+            if ( $sector->type eq 'D' ) {
                 $return .= ' ' . $sector->data;
             }
             elsif ( $sector->type eq 'A' || $sector->type eq 'H' ) {
